@@ -1,12 +1,18 @@
+#
+# Copyright (C) 2022 The Android Open Source Project
+#
+# SPDX-License-Identifier: Apache-2.0
+#
+
 from argparse import ArgumentParser
 from pathlib import Path
+from sebaubuntu_libs.liblogging import setup_logging
 from twrpdtgen import __version__ as version, current_path
-from twrpdtgen.devicetree import DeviceTree
-from twrpdtgen.utils.logging import setup_logging
+from twrpdtgen.device_tree import DeviceTree
 
 def main():
 	print(f"TWRP device tree generator\n"
-		  f"Version {version}\n")
+	      f"Version {version}\n")
 
 	parser = ArgumentParser(prog='python3 -m twrpdtgen')
 
@@ -28,7 +34,7 @@ def main():
 
 	setup_logging(args.debug)
 
-	device_tree = DeviceTree(image=args.image, debug=args.debug)
+	device_tree = DeviceTree(image=args.image)
 	folder = device_tree.dump_to_folder(args.output, git=args.git)
 
 	print(f"\nDone! You can find the device tree in {folder}")
